@@ -1,6 +1,7 @@
 
-from generalpackager.api.shared import _SharedAPI
-from generallibrary import Ver, Date, Recycle, get
+from generalpackager.api.shared import _SharedAPI, _SharedOwner, _SharedName
+
+from generallibrary import Ver, Date, get
 from generalfile import Path
 
 import requests
@@ -22,19 +23,16 @@ def download(url, path):
     return path
 
 
-class PyPI(Recycle, _SharedAPI):
+class PyPI(_SharedAPI, _SharedOwner, _SharedName):
     """ Tools to interface pypi.org """
-    _recycle_keys = {"name": str, "owner": str}
+    DEFAULT_OWNER = "Mandera"
 
     def __init__(self, name=None, owner=None):
-        if name is None:
-            name = "generalpackager"
-        if owner is None:
-            owner = "Mandera"
-        self.name = name
-        self.owner = owner
+        pass
 
-        self.url = f"https://pypi.org/project/{self.name}/"
+    @property
+    def url(self):
+        return f"https://pypi.org/project/{self.name}/"
 
     def exists(self):
         """ Return whether this API's target exists. """
@@ -62,9 +60,10 @@ class PyPI(Recycle, _SharedAPI):
         """ Get a set of a owner's packages' names on PyPI. """
         return set(re.findall("/project/(.*)/", requests.get(f"https://pypi.org/user/{self.owner}/").text))
 
-    # Todo: Find a faster fetch for latest PyPI version and datetime.
     def get_version(self):
-        """ Get version of latest publish on PyPI. """
+        """ Get version of latest publish on PyPI.
+
+            Todo: Find a faster fetch for latest PyPI version and datetime. """
         version = get(re.findall(f"{self.name} ([.0-9]+)\n", requests.get(self.url).text), 0)
         return Ver(version) if version else None
 
