@@ -1,5 +1,5 @@
 from generalfile import Path
-from generallibrary import NetworkDiagram, Log
+from generallibrary import NetworkDiagram, Log, deco_cache
 
 from generalpackager.api.localrepo.base.localrepo_target import _SharedTarget
 from generalpackager.api.shared import _SharedAPI, _SharedName, _SharedPath
@@ -32,6 +32,8 @@ class Packager(NetworkDiagram,
 
     Packages = Packages
 
+    Packager = ...
+
     def __init__(self, name=None, path=None, target=..., github_owner=None, pypi_owner=None):
         """ Storing pars as is. Name and target have some custom properties. """
         self._target = target
@@ -67,6 +69,7 @@ class Packager(NetworkDiagram,
                 packager.github.download()
 
     @staticmethod
+    @deco_cache()
     def summary_packagers():
         """ Packagers to hold summary of environment. """
         return [
@@ -87,7 +90,8 @@ class Packager(NetworkDiagram,
                 self.set_parent(parent=packager)
 
     def __repr__(self):
-        info = [self.target]
+        """ :param generalpackager.Packager self: """
+        info = [self.target or "No Target"]
         if self.path is None:
             info.append("No Path")
         info = str(info).replace("'", "")
