@@ -291,8 +291,8 @@ class _PackagerFiles:
         # Table of contents
         contents = Markdown(header="Contents", parent=markdown)
 
-        # Examples
-        self.get_examples_markdown().set_parent(parent=markdown)
+        # Mermaid
+        self.get_mermaid_markdown().set_parent(parent=markdown)
 
         # Installation
         self.get_installation_markdown().set_parent(parent=markdown)
@@ -300,6 +300,9 @@ class _PackagerFiles:
         # Information
         self.get_information_markdown().set_parent(parent=markdown)
 
+        # Examples
+        self.get_examples_markdown().set_parent(parent=markdown)
+
         # Attributes
         self.get_attributes_markdown().set_parent(parent=markdown)
 
@@ -318,24 +321,22 @@ class _PackagerFiles:
         return markdown
 
     def generate_personal_readme(self):
-        """ Generate personal readme markdown and overwrite README.md in local repo.
+        """ Generate personal readme markdown.
 
             :param generalpackager.Packager self: """
-        # ordered_packagers = type(self)().get_ordered_packagers()
         ordered_packagers = self.get_ordered_packagers(include_private=False)
 
         # Description
-        markdown = Markdown(header="ManderaGeneral").add_list_lines(
-            "A collection of connected packages.",
-            "Violently updated with little regard for backwards compatability.",
-            "Automatic workflows to unittest, sync and publish.",
-        )
+        markdown = self.get_org_description_markdown()
+
+        # Mermaid
+        self.get_mermaid_markdown().set_parent(parent=markdown)
 
         # Package information
         self.get_information_markdown(*ordered_packagers).set_parent(parent=markdown)
 
-        # Todos
-        self.get_todos_markdown(*ordered_packagers).set_parent(parent=markdown)
+        # Contributions
+        self.get_contributions_markdown().set_parent(parent=markdown)
 
         # Generation timestamp
         self.get_footnote_markdown(commit=False).set_parent(parent=markdown)
@@ -364,7 +365,8 @@ class _PackagerFiles:
             :param generalpackager.Packager self: """
         top = CodeLine()
         top.add_node(CodeLine(f"from generalpackager import Packager", space_before=1, space_after=1))
-        top.add_node(CodeLine(f"""Packager("{self.name}").generate_localfiles(print_out=True)""", space_after=50))
+        main = top.add_node(CodeLine(f'if __name__ == "__main__":'))
+        main.add_node(CodeLine(f"""Packager("{self.name}").generate_localfiles(print_out=True)""", space_after=50))
 
         return top
 
