@@ -6,6 +6,10 @@ import re
 
 
 class _PackagerMarkdown:
+    CROSS = "❌"
+    CHECK = "✔️"
+    NO_DEP = "*No dependencies*"
+
     """ Contains methods to generate readme sections from arguments. """
     def get_badges_dict(self):
         """ Get badges as a dict.
@@ -84,10 +88,7 @@ class _PackagerMarkdown:
 
     def get_description_markdown(self):
         """ :param generalpackager.Packager self: """
-        part_of = f"This package and {len(self.get_all()) - 1} other make up {Markdown.link(text='ManderaGeneral', url='https://github.com/ManderaGeneral')}."
-
         return Markdown(self.localrepo.metadata.description, header=self.name)
-        # return Markdown(self.localrepo.metadata.description, "\n", part_of, header=self.name)
 
     def get_information_markdown(self, *packagers):
         """ Get information table.
@@ -101,28 +102,43 @@ class _PackagerMarkdown:
 
         list_of_dicts = []
         for packager in packagers:
-            # attrs = packager._get_attributes_view().count("\n")
-            # untested_attrs = len(packager.get_untested_objInfo_dict())
-            # test_percentage = floor((attrs - untested_attrs) / attrs * 100, 1) if attrs else 100
+            package = Markdown.link(text=packager.name, url=packager.github.url)
+            ver = Markdown.link(text=packager.localrepo.metadata.version, url=packager.pypi.url)
+            latest_release = packager.get_latest_release()
+            python = ", ".join([Markdown.link(text=ver, url=f"{python_url}{str(ver).replace('.', '')}0/") for ver in packager.python])
+            platform = ", ".join(map(str.capitalize, packager.os))
+            cover = self.CROSS if packager.localrepo.coverage is None else f"{packager.localrepo.coverage} %"
 
             list_of_dicts.append({
-                "Package": Markdown.link(text=packager.name, url=packager.github.url),
-                "Ver": Markdown.link(text=packager.localrepo.metadata.version, url=packager.pypi.url),
-                "Latest Release": packager.get_latest_release(),
-                "Python": ", ".join([Markdown.link(text=ver, url=f"{python_url}{str(ver).replace('.', '')}0/") for ver in packager.python]),
-                "Platform": ", ".join(map(str.capitalize, packager.os)),
-                "Lvl": packager.get_ordered_index(),
-                "Todo": Markdown.link(text=len(packager.get_todos()), url=f"{packager.github.url}#{self._todo_header}"),
-                "Cover": f"{packager.localrepo.coverage} %",
+                "Package": package,
+                "Ver": ver,
+                "Latest Release": latest_release,
+                "Python": python,
+                "Platform": platform,
+                "Cover": cover,
             })
-        markdown.add_table_lines(*list_of_dicts, sort_by=["Lvl", "Package"])
+        markdown.add_table_lines(*list_of_dicts, sort_by=["Package"])
         return markdown
 
+    def _get_package_string(self, name):
+        if name == self.NO_DEP:
+            return self.NO_DEP
+        else:
+            return Markdown.link(name, url=f"https://pypi.org/project/{name}", href=True)
+
+    def _checked(self, packages, dependency):
+        if dependency in packages:
+            return self.CHECK
+        elif dependency == self.NO_DEP:
+            return self.CHECK
+        else:
+            return self.CROSS
+
     def get_installation_markdown(self):
         """ Get install markdown.
 
             :param generalpackager.Packager self: """
-        markdown = Markdown(header="Installation")
+        markdown = Markdown(header="Installation showing dependencies")
 
         dependencies_required = self.localrepo.metadata.install_requires.copy()
         dependencies_optional = list(set().union(*self.localrepo.metadata.extras_require.values()))
@@ -133,10 +149,15 @@ class _PackagerMarkdown:
 
         list_of_dicts = []
 
-        for command, packages in options.items():
-            row = {"Command": f"`pip install {command}`"}
-            for dependency in dependencies_required + dependencies_optional:
-                row[Markdown.link(dependency, url=f"https://pypi.org/project/{dependency}", href=True)] = "Yes" if dependency in packages else "No"
+        all_deps = dependencies_required + dependencies_optional
+        if not all_deps:
+            all_deps = [self.NO_DEP]
+
+        for dependency in all_deps:
+            row = {"`pip install`": self._get_package_string(name=dependency)}
+            for command, packages in options.items():
+                pip_install = f"`{command}`"
+                row[pip_install] = self._checked(packages=packages, dependency=dependency)
             list_of_dicts.append(row)
 
         markdown.add_table_lines(*list_of_dicts)
@@ -266,17 +287,33 @@ class _PackagerMarkdown:
         return markdown
 
     def get_contributions_markdown(self):
+        """ :param generalpackager.Packager self: """
         markdown = Markdown(header="Contributions")
         markdown.add_lines(
-            "Issue-creation and discussion is most welcome!",
+            "Issue-creation and discussions are most welcome!",
             "",
-            "Pull requests are **not wanted**, please discuss with me before investing any time."
+            "Pull requests are not wanted, please discuss with me before investing any time"
         )
         return markdown
 
+    def get_mermaid_markdown(self):
+        """ :param generalpackager.Packager self: """
+        nodes = self.get_ordered_packagers(include_private=False)
+        # nodes = self.get_parents(depth=-1, include_self=True)
+        repr_func = lambda pkg: pkg.simple_name
+        url_func = lambda pkg: pkg.github.url
+        highlight_self = True
+        markdown = self.mermaid(nodes=nodes, repr_func=repr_func, url_func=url_func, highlight_self=highlight_self)
+        markdown.header = "Dependency Diagram"
+        return markdown
 
-
-
+    def get_org_description_markdown(self):
+        """ :param generalpackager.Packager self: """
+        return Markdown(header="ManderaGeneral").add_list_lines(
+            "A collection of connected packages.",
+            "Violently updated with little regard for backwards compatability.",
+            "Automatic workflows to unittest, sync and publish.",
+        )
 
 
 
