@@ -1,5 +1,5 @@
 
-from generallibrary import remove_duplicates, deco_cache, Log
+from generallibrary import remove_duplicates, deco_cache, Log, Timer, flatten
 
 from itertools import chain
 
@@ -17,7 +17,7 @@ class _PackagerRelations:
         if self.target == self.Targets.python:
             names.update(self.localrepo.metadata.install_requires)
 
-        return list({type(self)(name) for name in names if not only_general or self.name_is_general(name)})
+        return {type(self)(name) for name in names if not only_general or self.name_is_general(name)}
 
         # packagers = {type(self)(localmodule.name) for localmodule in self.localmodule.get_dependencies() if not only_general or self.name_is_general(localmodule.name)}
         # packagers.update({type(self)(name) for name in self.localrepo.metadata.install_requires if not only_general or self.name_is_general(name)})
@@ -34,6 +34,7 @@ class _PackagerRelations:
         return list(packagers)
 
     @classmethod
+    @deco_cache()
     def get_ordered_packagers(cls, include_private=True, include_summary_packagers=False):
         """ Get a list of enabled ordered packagers from the dependency chain, sorted by name in each lvl.
 
@@ -41,10 +42,9 @@ class _PackagerRelations:
             :param include_private:
             :param include_summary_packagers:
             :rtype: list[generalpackager.Packager] """
-        packager = cls()
-        packagers = [packager for packager_set in packager.get_ordered(flat=False) for packager in sorted(packager_set, key=lambda x: x.name)]
-
-        packagers = remove_duplicates(packagers)
+        packagers_by_layer = cls().get_ordered(flat=False)
+        sorted_layers = [sorted(layer, key=lambda pkg: pkg.name) for layer in packagers_by_layer]
+        packagers = flatten(sorted_layers)
 
         if not include_private:
             packagers = [packager for packager in packagers if not packager.localrepo.metadata.private]
@@ -66,14 +66,14 @@ class _PackagerRelations:
         """ Return a set of general packagers that have been bumped.
 
             :param generalpackager.Packager self: """
-        return {packager for packager in self.get_all() if packager.is_bumped()}
+        return {packager for packager in self.get_ordered_packagers() if packager.is_bumped()}
 
     def general_changed_dict(self, aesthetic=None):
         """ Return a dict of general packagers with changed files comparing to github.
 
             :param generalpackager.Packager self:
             :param aesthetic: """
-        return {packager: files for packager in self.get_all() if (files := packager.compare_local_to_github(aesthetic=aesthetic))}
+        return {packager: files for packager in self.get_ordered_packagers() if (files := packager.compare_local_to_github(aesthetic=aesthetic))}
 
     @deco_cache()
     def get_untested_objInfo_dict(self):
